@@ -8,9 +8,12 @@ from .types import (
     Record,
     Stream,
     Subscription,
+    Shard,
+    ShardOffset,
+    SpecialOffset,
 )
 
-__version__ = "0.1.0"
+__version__ = "0.2.0"
 
 __all__ = [
     "insecure_client",
@@ -23,4 +26,7 @@ __all__ = [
     "Record",
     "Stream",
     "Subscription",
+    "Shard",
+    "ShardOffset",
+    "SpecialOffset",
 ]
